tryBigInt abstract method
Returns a value at key as BigInt or null if missing.
If provided min and max are used to clamp the returned value.
null is returned if an underlying value is unavailable or cannot be
converted to BigInt.
Implementation
BigInt? tryBigInt(K key, {BigInt? min, BigInt? max});