tryInt abstract method
Returns a value at key as int or null if missing.
If provided min and max are used to clamp the returned value.
null is returned if an underlying value is unavailable or cannot be
converted to int.
Implementation
int? tryInt(K key, {int? min, int? max});