tryId method
Returns a value at key as Identifier or null if missing.
null is returned if an underlying value is unavailable or cannot be
converted to Identifier.
Implementation
@override
Identifier? tryId(K key) {
try {
return getId(key);
} on Exception {
return null;
}
}